#ifndef GRAPHICS_HPP
#define GRAPHICS_HPP

#include <SDL.h>
#define NO_SDL_GLEXT
#define __glext_h_
#include <SDL_opengl.h>
#undef __glext_h_
#include <Graphics/glext.h>
#include <string>

#include <Vector/Vector.hpp>

using std::string;

namespace Graphics {
	//these can be set up before calling init()
	extern Vector2ui screen; //default 800
	extern bool fullscreen; //default false

	//convenience function for screen aspect ratio.
	inline double aspect() {
		return (double)screen.x / (double)screen.y;
	}
	inline float aspectf() {
		return (float)screen.x / (float)screen.y;
	}

	enum {
		NEED_ACCUM = 1 << 0,
		NEED_STENCIL = 1 << 1,
		NEED_VSYNC = 1 << 2,
	};
	//set up graphics output. lets you know if it fails.
	bool init(int flags = 0);

	//tear down graphics output.
	void deinit();

	//check if GL is initialized.
	bool initialized();

	//register a function to be called next init.
	//call only if !is_initialized().
	void on_init(void (*func)(void *), void *data);

	//helper function for gl code.
	//LOG_WARNING()'s all gl errors along with the 'where' string.
	void gl_errors(string const &where);
}


#endif
